@@ -28,27 +28,26 @@
  * - Extended with custom weights and maxDistance
  */
 double lv_dist(
-  unsigned int *a, int na, 
-  unsigned int *b, int nb, 
+  unsigned int *a, int na, // source
+  unsigned int *b, int nb, // target
   double *weight, 
   double *scores){
   if (!na){
-    return (double) nb;
+    return (double) nb * weight[1]; // del score
   }
   if (!nb){
-    return (double) na;
+    return (double) na * weight[0]; // ins score
   }
 
   int i, j;
   int I = na+1, L = na+1, J = nb+1;
   double sub;
 
-
   for ( i = 0; i < I; ++i ){
-    scores[i] = i;
+    scores[i] = i * weight[1];
   }
   for ( j = 1; j < J; ++j, L += I ){
-   scores[L] = j;
+   scores[L] = j * weight[0];
   }
 
   int M;
